<h1 align="center">&lt;code-syntax /&gt;</h1>

<p align="center">
code syntax highlight custom element
</p>

<p align="center">
   <a href="#install">        🔧 <strong>Install</strong></a>
 · <a href="#example">        🧩 <strong>Example</strong></a>
 · <a href="#api">            📜 <strong>API docs</strong></a>
 · <a href="https://github.com/stagas/code-syntax/releases"> 🔥 <strong>Releases</strong></a>
 · <a href="#contribute">     💪🏼 <strong>Contribute</strong></a>
 · <a href="https://github.com/stagas/code-syntax/issues">   🖐️ <strong>Help</strong></a>
</p>

***

## Install

```sh
$ npm i code-syntax
```

**[See it in action!](https://stagas.github.io/code-syntax/)**

## Example

```js
import 'plenty-themes/laser.css'
import 'code-syntax/themes/default.css'

import { CodeSyntaxElement, languages } from 'code-syntax'

customElements.define('code-syntax', CodeSyntaxElement)

languages.js = import('code-syntax/languages/js')
```

```html
<pre><code-syntax language="js" theme="laser">
class Vector {
  x: number
  y: number
  constructor(x: number, y: number) {
    this.x = x
    this.y = y
  }
  add(v: Vector): Vector {
    return new Vector(this.x + v.x, this.y + v.y)
  }
}
</code-syntax></pre>
```

## API

<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

#### Table of Contents

*   [CodeSyntaxElement](#codesyntaxelement)
*   [compile](#compile)
    *   [Parameters](#parameters)
*   [syntax](#syntax)
    *   [Parameters](#parameters-1)

### CodeSyntaxElement

[src/element.ts:50-123](https://github.com/stagas/code-syntax/blob/51b37e0d1389f9bf691c9ef6e9f47df1c29af917/src/element.ts#L50-L123 "Source code on GitHub")

**Extends HTMLElement**

CodeSyntax custom element

```js
import { CodeSyntaxElement } from 'code-syntax'
customElements.define('code-syntax', CodeSyntaxElement)
```

### compile

[src/syntax.ts:22-45](https://github.com/stagas/code-syntax/blob/51b37e0d1389f9bf691c9ef6e9f47df1c29af917/src/syntax.ts#L22-L45 "Source code on GitHub")

Compiles a syntax definition.

```js
const r = await compile({
  foo: /[a-z]/,
  bar: /[0-9]/,
})
```

#### Parameters

*   `def` **(SyntaxDefinition | [Promise](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Promise)<{default: SyntaxDefinition}>)** The syntax definition to compile. Can be a promise returned by `import()`.
*   `keys` **[Set](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Set)<[string](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)>** &#x20;(optional, default `new Set()`)

Returns **[Promise](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Promise)\<RegExpMapped>**&#x20;

### syntax

[src/syntax.ts:66-77](https://github.com/stagas/code-syntax/blob/51b37e0d1389f9bf691c9ef6e9f47df1c29af917/src/syntax.ts#L66-L77 "Source code on GitHub")

Syntax highlights a string as html with the given syntax.

```js
const regexp = await compile({
  foo: /[a-z]+/,
  bar: [
    /[0-9]+/,
    {
      bar: /[0-5]+/,
    },
  ],
})
const html = syntax(regexp, 'hello 123 789 world')
```

#### Parameters

*   `regexp` **RegExpMapped** The syntax definition returned by `compile()`
*   `s` **[string](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** The string to highlight.

Returns **[string](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)**&#x20;

## Contribute

[Fork](https://github.com/stagas/code-syntax/fork) or
[edit](https://github.dev/stagas/code-syntax) and submit a PR.

All contributions are welcome!

## License

MIT © 2021
[stagas](https://github.com/stagas)
